# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/love/voodoo/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Love\\Voodoo\\": "packages/love/voodoo/src",
            "Love\\Voodoo\\Seeders\\": "packages/love/voodoo/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Love\Voodoo\Providers\VoodooServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Voodoo'  => Love\Voodoo\Facades\Voodoo::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Love\\Voodoo\\Seeders\\VoodooTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Love\Voodoo\Providers\VoodooServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Love\Voodoo\Providers\VoodooServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Love\Voodoo\Providers\VoodooServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/voodoo/{modulename}

**User**

    http://path-to-route-folder/user/voodoo/{modulename}

**Public**

    http://path-to-route-folder/voodoos


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/voodoo/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/voodoo/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/voodoo/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/voodoo/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/voodoo/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/voodoo/{modulename}/{slug}
    METHOD: GET